summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLaria Carolin Chabowski <laria@laria.me>2020-09-21 20:46:15 +0200
committerLaria Carolin Chabowski <laria@laria.me>2020-09-21 20:46:15 +0200
commitceb262e08027531717f1a16faafc343e8d9656e3 (patch)
tree87fdc916042efeebcacc1ef66dd99a969b8e4c4e
parentbf4d0598030b83be337bc505de842f7766009467 (diff)
downloadste-ceb262e08027531717f1a16faafc343e8d9656e3.tar.gz
ste-ceb262e08027531717f1a16faafc343e8d9656e3.tar.bz2
ste-ceb262e08027531717f1a16faafc343e8d9656e3.zip
Move to r7r namespace and r7r composer package vendor2.0.0
Let's face it, no one but my CMS Ratatöskr (r7r for short) uses this template engine anyway. Also it's a good excuse to get rid of more remnants of my old kch42 nickname.
-rw-r--r--README.markdown2
-rw-r--r--composer.json4
-rw-r--r--example/index.php2
-rw-r--r--src/ste/ASTNode.php2
-rw-r--r--src/ste/BreakException.php2
-rw-r--r--src/ste/Calc.php2
-rw-r--r--src/ste/CantLoadTemplate.php2
-rw-r--r--src/ste/CantSaveTemplate.php2
-rw-r--r--src/ste/ContinueException.php2
-rw-r--r--src/ste/FatalRuntimeError.php2
-rw-r--r--src/ste/FilesystemStorageAccess.php2
-rw-r--r--src/ste/Misc.php2
-rw-r--r--src/ste/ParseCompileError.php2
-rw-r--r--src/ste/Parser.php2
-rw-r--r--src/ste/RuntimeError.php2
-rw-r--r--src/ste/STECore.php2
-rw-r--r--src/ste/STEStandardLibrary.php2
-rw-r--r--src/ste/Scope.php2
-rw-r--r--src/ste/StorageAccess.php2
-rw-r--r--src/ste/StorageAccessFailure.php2
-rw-r--r--src/ste/TagNode.php2
-rw-r--r--src/ste/TextNode.php2
-rw-r--r--src/ste/Transcompiler.php48
-rw-r--r--src/ste/VarNotInScope.php2
-rw-r--r--src/ste/VariableNode.php2
-rw-r--r--ste.php36
-rw-r--r--steloader.php2
-rw-r--r--tests/functional/BaseTest.php2
-rw-r--r--tests/functional/TestStorage.php2
-rw-r--r--tests/functional/test_array/Test.php2
-rw-r--r--tests/functional/test_blocks/Test.php2
-rw-r--r--tests/functional/test_closure/Test.php2
-rw-r--r--tests/functional/test_escapes/Test.php2
-rw-r--r--tests/functional/test_foreach/Test.php2
-rw-r--r--tests/functional/test_getset/Test.php2
-rw-r--r--tests/functional/test_loop/Test.php2
-rw-r--r--tests/functional/test_mktag/Test.php2
-rw-r--r--tests/functional/test_pseudotags/Test.php2
-rw-r--r--tests/functional/test_recursive/Test.php2
-rw-r--r--tests/functional/test_scoping/Test.php2
-rw-r--r--tests/functional/test_short/Test.php2
-rw-r--r--tests/functional/test_short_for_additional_attribs/Test.php2
-rw-r--r--tests/functional/test_simple/Test.php2
-rw-r--r--tests/functional/test_static_numeric_array_access/Test.php2
-rw-r--r--tests/functional/test_tagname/Test.php4
-rw-r--r--tests/functional/test_trailing_closing_array_bracket/Test.php2
-rw-r--r--tests/unit/ParserTest.php10
47 files changed, 93 insertions, 93 deletions
diff --git a/README.markdown b/README.markdown
index 9f6d299..9018a41 100644
--- a/README.markdown
+++ b/README.markdown
@@ -9,7 +9,7 @@ Get it via composer / packagist
[Composer](https://getcomposer.org) is a dependency manager and package manager for PHP. Using composer is the recommended way of installing STE.
-Just put `kch42/ste` in your requirements (I suggest using the version `1.*`) and execute `composer install`. Then include composer's autoloader and you can simply use all stuff in the `\kch42\ste` namespace without further `require`s or `include`s. Awesome!
+Just put `r7r/ste` in your requirements (I suggest using the version `1.*`) and execute `composer install`. Then include composer's autoloader and you can simply use all stuff in the `\r7r\ste` namespace without further `require`s or `include`s. Awesome!
Requirements
diff --git a/composer.json b/composer.json
index a83c26c..eb828f3 100644
--- a/composer.json
+++ b/composer.json
@@ -1,11 +1,11 @@
{
- "name": "kch42/ste",
+ "name": "r7r/ste",
"require": {
"php": ">=7.3.0"
},
"autoload": {
"psr-4": {
- "kch42\\ste\\": "src/ste"
+ "r7r\\ste\\": "src/ste"
}
},
"autoload-dev": {
diff --git a/example/index.php b/example/index.php
index 0213c34..f62e8a4 100644
--- a/example/index.php
+++ b/example/index.php
@@ -3,7 +3,7 @@
# Example program to demonstrate the STE...
require_once(dirname(__FILE__) . "/../steloader.php");
-use \kch42\ste;
+use r7r\ste;
# Initialize an STECore instance
$ste = new ste\STECore(
diff --git a/src/ste/ASTNode.php b/src/ste/ASTNode.php
index 4eb0348..efb7d65 100644
--- a/src/ste/ASTNode.php
+++ b/src/ste/ASTNode.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
abstract class ASTNode
{
diff --git a/src/ste/BreakException.php b/src/ste/BreakException.php
index f91cf6a..8dea18f 100644
--- a/src/ste/BreakException.php
+++ b/src/ste/BreakException.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
class BreakException extends \Exception
{
diff --git a/src/ste/Calc.php b/src/ste/Calc.php
index 660943d..39608c3 100644
--- a/src/ste/Calc.php
+++ b/src/ste/Calc.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
/**
* Class Calc contains static methods needed by <ste:calc />
diff --git a/src/ste/CantLoadTemplate.php b/src/ste/CantLoadTemplate.php
index 92604cc..655248f 100644
--- a/src/ste/CantLoadTemplate.php
+++ b/src/ste/CantLoadTemplate.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
/**
* An exception that a {@see StorageAccess} implementation can throw, if it is unable to load a template.
diff --git a/src/ste/CantSaveTemplate.php b/src/ste/CantSaveTemplate.php
index 92cdfe7..f0e64f6 100644
--- a/src/ste/CantSaveTemplate.php
+++ b/src/ste/CantSaveTemplate.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
/**
* An exception that a {@see StorageAccess} implementation can throw, if it is unable to save a template.
diff --git a/src/ste/ContinueException.php b/src/ste/ContinueException.php
index 784166e..b2606ac 100644
--- a/src/ste/ContinueException.php
+++ b/src/ste/ContinueException.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
class ContinueException extends \Exception
{
diff --git a/src/ste/FatalRuntimeError.php b/src/ste/FatalRuntimeError.php
index 3f5183f..39bbd44 100644
--- a/src/ste/FatalRuntimeError.php
+++ b/src/ste/FatalRuntimeError.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
/**
* An Exception a tag can throw, if a fatal (irreparable) runtime error occurred.
diff --git a/src/ste/FilesystemStorageAccess.php b/src/ste/FilesystemStorageAccess.php
index ead2757..bbc169b 100644
--- a/src/ste/FilesystemStorageAccess.php
+++ b/src/ste/FilesystemStorageAccess.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
/**
* The default {@see StorageAccess} implementation for loading / saving templates into a directory structure.
diff --git a/src/ste/Misc.php b/src/ste/Misc.php
index 7118b28..e1ce2f9 100644
--- a/src/ste/Misc.php
+++ b/src/ste/Misc.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
class Misc
{
diff --git a/src/ste/ParseCompileError.php b/src/ste/ParseCompileError.php
index bc0c252..55a908a 100644
--- a/src/ste/ParseCompileError.php
+++ b/src/ste/ParseCompileError.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
/**
* An exception thrown by the parser or compiler
diff --git a/src/ste/Parser.php b/src/ste/Parser.php
index a2f966c..4db8710 100644
--- a/src/ste/Parser.php
+++ b/src/ste/Parser.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
use LogicException;
diff --git a/src/ste/RuntimeError.php b/src/ste/RuntimeError.php
index 51fd29d..e7d80d5 100644
--- a/src/ste/RuntimeError.php
+++ b/src/ste/RuntimeError.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
/**
* An Exception that a tag can throw, if a non-fatal runtime error occurred.
diff --git a/src/ste/STECore.php b/src/ste/STECore.php
index a232616..a53e652 100644
--- a/src/ste/STECore.php
+++ b/src/ste/STECore.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
use Exception;
diff --git a/src/ste/STEStandardLibrary.php b/src/ste/STEStandardLibrary.php
index cd23fdf..b412440 100644
--- a/src/ste/STEStandardLibrary.php
+++ b/src/ste/STEStandardLibrary.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
class STEStandardLibrary
{
diff --git a/src/ste/Scope.php b/src/ste/Scope.php
index 2ab4e7f..dad1c42 100644
--- a/src/ste/Scope.php
+++ b/src/ste/Scope.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
class Scope implements \ArrayAccess
{
diff --git a/src/ste/StorageAccess.php b/src/ste/StorageAccess.php
index ec7f6bc..5118544 100644
--- a/src/ste/StorageAccess.php
+++ b/src/ste/StorageAccess.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
/**
* A StorageAccess implementation is used to access the templates from any storage.
diff --git a/src/ste/StorageAccessFailure.php b/src/ste/StorageAccessFailure.php
index 50dfc8a..15286ac 100644
--- a/src/ste/StorageAccessFailure.php
+++ b/src/ste/StorageAccessFailure.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
abstract class StorageAccessFailure extends \Exception
{
diff --git a/src/ste/TagNode.php b/src/ste/TagNode.php
index ce713c0..fe4d5ff 100644
--- a/src/ste/TagNode.php
+++ b/src/ste/TagNode.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
class TagNode extends ASTNode
{
diff --git a/src/ste/TextNode.php b/src/ste/TextNode.php
index c46d71f..c287b50 100644
--- a/src/ste/TextNode.php
+++ b/src/ste/TextNode.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
class TextNode extends ASTNode
{
diff --git a/src/ste/Transcompiler.php b/src/ste/Transcompiler.php
index 3955754..ec37a71 100644
--- a/src/ste/Transcompiler.php
+++ b/src/ste/Transcompiler.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
/**
* Contains the STE compiler. You'll only need this, if you want to manually compile a STE template.
@@ -27,23 +27,23 @@ class Transcompiler
/** @var callable[] builtins */
self::$builtins = [
- "if" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_if"]),
- "cmp" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_cmp"]),
- "not" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_not"]),
- "even" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_even"]),
- "for" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_for"]),
- "foreach" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_foreach"]),
- "infloop" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_infloop"]),
- "break" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_break"]),
- "continue" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_continue"]),
- "block" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_block"]),
- "load" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_load"]),
- "mktag" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_mktag"]),
- "tagcontent" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_tagcontent"]),
- "set" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_set"]),
- "setlocal" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_setlocal"]),
- "get" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_get"]),
- "calc" => self::mark_builtin_callable(["\\kch42\\ste\\Transcompiler", "builtin_calc"])
+ "if" => self::mark_builtin_callable([self::class, "builtin_if"]),
+ "cmp" => self::mark_builtin_callable([self::class, "builtin_cmp"]),
+ "not" => self::mark_builtin_callable([self::class, "builtin_not"]),
+ "even" => self::mark_builtin_callable([self::class, "builtin_even"]),
+ "for" => self::mark_builtin_callable([self::class, "builtin_for"]),
+ "foreach" => self::mark_builtin_callable([self::class, "builtin_foreach"]),
+ "infloop" => self::mark_builtin_callable([self::class, "builtin_infloop"]),
+ "break" => self::mark_builtin_callable([self::class, "builtin_break"]),
+ "continue" => self::mark_builtin_callable([self::class, "builtin_continue"]),
+ "block" => self::mark_builtin_callable([self::class, "builtin_block"]),
+ "load" => self::mark_builtin_callable([self::class, "builtin_load"]),
+ "mktag" => self::mark_builtin_callable([self::class, "builtin_mktag"]),
+ "tagcontent" => self::mark_builtin_callable([self::class, "builtin_tagcontent"]),
+ "set" => self::mark_builtin_callable([self::class, "builtin_set"]),
+ "setlocal" => self::mark_builtin_callable([self::class, "builtin_setlocal"]),
+ "get" => self::mark_builtin_callable([self::class, "builtin_get"]),
+ "calc" => self::mark_builtin_callable([self::class, "builtin_calc"])
];
}
@@ -156,7 +156,7 @@ class Transcompiler
},
$operators
));
- $code .= "default: throw new \\kch42\\ste\\RuntimeError('Unknown operator in <ste:cmp>.');\n}\n";
+ $code .= "default: throw new \\r7r\\ste\\RuntimeError('Unknown operator in <ste:cmp>.');\n}\n";
}
return $code;
}
@@ -235,7 +235,7 @@ class Transcompiler
$loopbody = self::indent_code("{\n" . self::loopbody(self::indent_code($loopbody)) . "\n}\n");
if ($step === null) {
- $code .= "if(\$${loopname}_step == 0)\n\tthrow new \\kch42\\ste\\RuntimeError('step can not be 0 in <ste:for>.');\n";
+ $code .= "if(\$${loopname}_step == 0)\n\tthrow new \\r7r\\ste\\RuntimeError('step can not be 0 in <ste:for>.');\n";
$code .= "if(\$${loopname}_step > 0)\n{\n";
$code .= "\tfor(\$${loopname}_counter = \$${loopname}_start; \$${loopname}_counter <= \$${loopname}_stop; \$${loopname}_counter += \$${loopname}_step)\n";
$code .= $loopbody;
@@ -342,7 +342,7 @@ class Transcompiler
*/
private static function builtin_break(TagNode $ast): string
{
- return "throw new \\kch42\\ste\\BreakException();\n";
+ return "throw new \\r7r\\ste\\BreakException();\n";
}
/**
@@ -351,7 +351,7 @@ class Transcompiler
*/
private static function builtin_continue(TagNode $ast): string
{
- return "throw new \\kch42\\ste\\ContinueException();\n";
+ return "throw new \\r7r\\ste\\ContinueException();\n";
}
/**
@@ -421,7 +421,7 @@ class Transcompiler
$code .= self::_transcompile($ast->params["mandatory"]);
$code .= "\$outputstack_i--;\n\$mandatory_params = explode('|', array_pop(\$outputstack));\n";
- $fxbody .= "foreach(\$mandatory_params as \$mp)\n{\n\tif(!isset(\$params[\$mp]))\n\t\tthrow new \\kch42\\ste\\RuntimeError(\"\$mp missing in <ste:\" . $tagname . \">.\");\n}";
+ $fxbody .= "foreach(\$mandatory_params as \$mp)\n{\n\tif(!isset(\$params[\$mp]))\n\t\tthrow new \\r7r\\ste\\RuntimeError(\"\$mp missing in <ste:\" . $tagname . \">.\");\n}";
}
$fxbody .= self::_transcompile($ast->sub);
@@ -528,7 +528,7 @@ class Transcompiler
private static function loopbody(string $code): string
{
- return "try\n{\n" . self::indent_code($code) . "\n}\ncatch(\\kch42\\ste\\BreakException \$e) { break; }\ncatch(\\kch42\\ste\\ContinueException \$e) { continue; }\n";
+ return "try\n{\n" . self::indent_code($code) . "\n}\ncatch(\\r7r\\ste\\BreakException \$e) { break; }\ncatch(\\r7r\\ste\\ContinueException \$e) { continue; }\n";
}
/**
diff --git a/src/ste/VarNotInScope.php b/src/ste/VarNotInScope.php
index 6dc5eda..bc417a9 100644
--- a/src/ste/VarNotInScope.php
+++ b/src/ste/VarNotInScope.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
class VarNotInScope extends \Exception
{
diff --git a/src/ste/VariableNode.php b/src/ste/VariableNode.php
index cdffc3f..785e86a 100644
--- a/src/ste/VariableNode.php
+++ b/src/ste/VariableNode.php
@@ -1,6 +1,6 @@
<?php
-namespace kch42\ste;
+namespace r7r\ste;
class VariableNode extends ASTNode
{
diff --git a/steloader.php b/steloader.php
index 5e490be..f878f6f 100644
--- a/steloader.php
+++ b/steloader.php
@@ -9,7 +9,7 @@
function autoload_ste($cl)
{
$path = explode("\\", $cl);
- if (($path[0] == "kch42") && ($path[1] == "ste")) {
+ if (($path[0] == "r7r") && ($path[1] == "ste")) {
require_once(__DIR__ . "/src/ste/" . $path[2] . ".php");
}
}
diff --git a/tests/functional/BaseTest.php b/tests/functional/BaseTest.php
index ce045fb..3450600 100644
--- a/tests/functional/BaseTest.php
+++ b/tests/functional/BaseTest.php
@@ -4,7 +4,7 @@
namespace tests\functional;
use PHPUnit\Framework\TestCase;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
abstract class BaseTest extends TestCase
{
diff --git a/tests/functional/TestStorage.php b/tests/functional/TestStorage.php
index ff8512a..976008c 100644
--- a/tests/functional/TestStorage.php
+++ b/tests/functional/TestStorage.php
@@ -3,7 +3,7 @@
namespace tests\functional;
-use kch42\ste\StorageAccess;
+use r7r\ste\StorageAccess;
class TestStorage implements StorageAccess
{
diff --git a/tests/functional/test_array/Test.php b/tests/functional/test_array/Test.php
index 85d0217..a34a694 100644
--- a/tests/functional/test_array/Test.php
+++ b/tests/functional/test_array/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_array;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_blocks/Test.php b/tests/functional/test_blocks/Test.php
index 05e8e09..76f2cda 100644
--- a/tests/functional/test_blocks/Test.php
+++ b/tests/functional/test_blocks/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_blocks;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_closure/Test.php b/tests/functional/test_closure/Test.php
index 012e4c6..04fab15 100644
--- a/tests/functional/test_closure/Test.php
+++ b/tests/functional/test_closure/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_closure;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_escapes/Test.php b/tests/functional/test_escapes/Test.php
index 5c2a2ab..a67a8a7 100644
--- a/tests/functional/test_escapes/Test.php
+++ b/tests/functional/test_escapes/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_escapes;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_foreach/Test.php b/tests/functional/test_foreach/Test.php
index 2fc3d91..0fc8a06 100644
--- a/tests/functional/test_foreach/Test.php
+++ b/tests/functional/test_foreach/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_foreach;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_getset/Test.php b/tests/functional/test_getset/Test.php
index 6f34500..7e71203 100644
--- a/tests/functional/test_getset/Test.php
+++ b/tests/functional/test_getset/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_getset;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_loop/Test.php b/tests/functional/test_loop/Test.php
index 05a76d7..f0b8df7 100644
--- a/tests/functional/test_loop/Test.php
+++ b/tests/functional/test_loop/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_loop;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_mktag/Test.php b/tests/functional/test_mktag/Test.php
index c850509..17d9347 100644
--- a/tests/functional/test_mktag/Test.php
+++ b/tests/functional/test_mktag/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_mktag;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_pseudotags/Test.php b/tests/functional/test_pseudotags/Test.php
index f64ff5f..62f386c 100644
--- a/tests/functional/test_pseudotags/Test.php
+++ b/tests/functional/test_pseudotags/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_pseudotags;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_recursive/Test.php b/tests/functional/test_recursive/Test.php
index d393791..1a3dc12 100644
--- a/tests/functional/test_recursive/Test.php
+++ b/tests/functional/test_recursive/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_recursive;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_scoping/Test.php b/tests/functional/test_scoping/Test.php
index b15f911..1405662 100644
--- a/tests/functional/test_scoping/Test.php
+++ b/tests/functional/test_scoping/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_scoping;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_short/Test.php b/tests/functional/test_short/Test.php
index 2b138f5..5728648 100644
--- a/tests/functional/test_short/Test.php
+++ b/tests/functional/test_short/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_short;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_short_for_additional_attribs/Test.php b/tests/functional/test_short_for_additional_attribs/Test.php
index e0e0934..3c66a18 100644
--- a/tests/functional/test_short_for_additional_attribs/Test.php
+++ b/tests/functional/test_short_for_additional_attribs/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_short_for_additional_attribs;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_simple/Test.php b/tests/functional/test_simple/Test.php
index e2b58d9..78b5ac0 100644
--- a/tests/functional/test_simple/Test.php
+++ b/tests/functional/test_simple/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_simple;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_static_numeric_array_access/Test.php b/tests/functional/test_static_numeric_array_access/Test.php
index 150b74a..0e5fecb 100644
--- a/tests/functional/test_static_numeric_array_access/Test.php
+++ b/tests/functional/test_static_numeric_array_access/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_static_numeric_array_access;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/functional/test_tagname/Test.php b/tests/functional/test_tagname/Test.php
index 38f26c2..6adda8c 100644
--- a/tests/functional/test_tagname/Test.php
+++ b/tests/functional/test_tagname/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_tagname;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
@@ -20,7 +20,7 @@ class Test extends BaseTest
"foo123baz",
"x0123",
];
-
+
foreach ($names as $name) {
$ste->register_tag(
$name,
diff --git a/tests/functional/test_trailing_closing_array_bracket/Test.php b/tests/functional/test_trailing_closing_array_bracket/Test.php
index a24f93c..586fb21 100644
--- a/tests/functional/test_trailing_closing_array_bracket/Test.php
+++ b/tests/functional/test_trailing_closing_array_bracket/Test.php
@@ -2,7 +2,7 @@
namespace tests\functional\test_trailing_closing_array_bracket;
-use kch42\ste\STECore;
+use r7r\ste\STECore;
use tests\functional\BaseTest;
class Test extends BaseTest
diff --git a/tests/unit/ParserTest.php b/tests/unit/ParserTest.php
index b559913..3784582 100644
--- a/tests/unit/ParserTest.php
+++ b/tests/unit/ParserTest.php
@@ -4,11 +4,11 @@
namespace tests\unit;
use PHPUnit\Framework\TestCase;
-use kch42\ste\Parser;
-use kch42\ste\TextNode;
-use kch42\ste\VariableNode;
-use kch42\ste\TagNode;
-use kch42\ste\ParseCompileError;
+use r7r\ste\Parser;
+use r7r\ste\TextNode;
+use r7r\ste\VariableNode;
+use r7r\ste\TagNode;
+use r7r\ste\ParseCompileError;
class ParserTest extends TestCase
{
diff --git a/ste.php b/ste.php
index 72d6eca..67285ca 100644
--- a/ste.php
+++ b/ste.php
@@ -2,7 +2,7 @@
namespace ste;
/* This file is for backwards compatibility only. Use an autoloader and the \kch42\ste namespace in new applications instead! */
require_once(__DIR__ . "/src/ste/Misc.php");
@@ -38,54 +38,54 @@ require_once(__DIR__ . "/src/ste/STECore.php");
/* Providing "proxy classes", so old applications can continue using the ste namespace */
-class ASTNode extends \kch42\ste\ASTNode
+class ASTNode extends \r7r\ste\ASTNode
{
}
-class TagNode extends \kch42\ste\TagNode
+class TagNode extends \r7r\ste\TagNode
{
}
-class TextNode extends \kch42\ste\TextNode
+class TextNode extends \r7r\ste\TextNode
{
}
-class VariableNode extends \kch42\ste\VariableNode
+class VariableNode extends \r7r\ste\VariableNode
{
}
-class ParseCompileError extends \kch42\ste\ParseCompileError
+class ParseCompileError extends \r7r\ste\ParseCompileError
{
}
-class RuntimeError extends \kch42\ste\RuntimeError
+class RuntimeError extends \r7r\ste\RuntimeError
{
}
-class FatalRuntimeError extends \kch42\ste\FatalRuntimeError
+class FatalRuntimeError extends \r7r\ste\FatalRuntimeError
{
}
-class StorageAccessFailure extends \kch42\ste\StorageAccessFailure
+class StorageAccessFailure extends \r7r\ste\StorageAccessFailure
{
}
-class CantLoadTemplate extends \kch42\ste\CantLoadTemplate
+class CantLoadTemplate extends \r7r\ste\CantLoadTemplate
{
}
-class CantSaveTemplate extends \kch42\ste\CantSaveTemplate
+class CantSaveTemplate extends \r7r\ste\CantSaveTemplate
{
}
-class FilesystemStorageAccess extends \kch42\ste\FilesystemStorageAccess
+class FilesystemStorageAccess extends \r7r\ste\FilesystemStorageAccess
{
}
-class Parser extends \kch42\ste\Parser
+class Parser extends \r7r\ste\Parser
{
}
-class Transcompiler extends \kch42\ste\Transcompiler
+class Transcompiler extends \r7r\ste\Transcompiler
{
}
-class STECore extends \kch42\ste\STECore
+class STECore extends \r7r\ste\STECore
{
}
-interface StorageAccess extends \kch42\ste\StorageAccess
+interface StorageAccess extends \r7r\ste\StorageAccess
{
}
/* We also put the storage mode constants here (they were outside of the interface before for some reason I can't remember...) */
-const MODE_SOURCE = \kch42\ste\StorageAccess::MODE_SOURCE;
-const MODE_TRANSCOMPILED = \kch42\ste\StorageAccess::MODE_TRANSCOMPILED;
+const MODE_SOURCE = \r7r\ste\StorageAccess::MODE_SOURCE;
+const MODE_TRANSCOMPILED = \r7r\ste\StorageAccess::MODE_TRANSCOMPILED;
@@ -2,7 +2,7 @@
namespace ste;
-/* This file is for backwards compatibility only. Use an autoloader and the \kch42\ste namespace in new applications instead! */
+/* This file is for backwards compatibility only. Use an autoloader and the \r7r\ste namespace in new applications instead! */
require_once(__DIR__ . "/src/ste/Misc.php");